@@ -1742,7 +1742,7 @@ pango_font_default_has_char (PangoFont *font,
 {
   PangoCoverage *coverage = pango_font_get_coverage (font, pango_language_get_default ());
   PangoCoverageLevel result = pango_coverage_get (coverage, wc);
-  pango_coverage_unref (coverage);
+  g_object_unref (coverage);
   return result != PANGO_COVERAGE_NONE;
 }
 
@@ -2374,11 +2374,79 @@ pango_font_family_default_is_variable (PangoFontFamily *family)
 }
 
 static void
-pango_font_family_class_init (PangoFontFamilyClass *class G_GNUC_UNUSED)
+pango_font_family_default_list_faces (PangoFontFamily   *family,
+                                      PangoFontFace   ***faces,
+                                      int               *n_faces)
 {
+  if (faces)
+    *faces = NULL;
+
+  if (n_faces)
+    *n_faces = 0;
+}
+
+enum {
+  PROP_ITEM_TYPE = 1,
+  PROP_N_ITEMS,
+  N_PROPERTIES
+};
+
+static GParamSpec *font_family_properties[N_PROPERTIES] = { NULL };
+
+static void
+pango_font_family_get_property (GObject    *object,
+                                guint       property_id,
+                                GValue     *value,
+                                GParamSpec *pspec)
+{
+  switch (property_id)
+    {
+    case PROP_ITEM_TYPE:
+      g_value_set_gtype (value, PANGO_TYPE_FONT);
+      break;
+
+    case PROP_N_ITEMS:
+      g_value_set_uint (value, pango_font_family_get_n_items (G_LIST_MODEL (object)));
+      break;
+
+    default:
+      G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+    }
+}
+
+static void
+pango_font_family_class_init (PangoFontFamilyClass *class)
+{
+  GObjectClass *gobject_class = G_OBJECT_CLASS (class);
+
+  gobject_class->get_property = pango_font_family_get_property;
+
   class->is_monospace = pango_font_family_default_is_monospace;
   class->is_variable = pango_font_family_default_is_variable;
   class->get_face = pango_font_family_real_get_face;
+  class->list_faces = pango_font_family_default_list_faces;
+
+  /**
+   * PangoFontFamily:item-type:
+   *
+   * The type of items contained in this list.
+   */
+  font_family_properties[PROP_ITEM_TYPE] =
+    g_param_spec_gtype ("item-type", "", "", G_TYPE_OBJECT,
+                        G_PARAM_READABLE | G_PARAM_STATIC_STRINGS);
+
+  /**
+   * PangoFontFamily:n-items:
+   *
+   * The number of items contained in this list.
+   */
+  font_family_properties[PROP_N_ITEMS] =
+    g_param_spec_uint ("n-items", "", "", 0, G_MAXUINT, 0,
+                       G_PARAM_READABLE | G_PARAM_STATIC_STRINGS);
+
+  g_object_class_install_properties (gobject_class,
+                                     N_PROPERTIES,
+                                     font_family_properties);
 }
 
 static void
@@ -2420,6 +2488,12 @@ pango_font_family_get_name (PangoFontFamily  *family)
  *
  * The faces in a family share a common design, but differ in slant, weight,
  * width and other aspects.
+ *
+ * Note that the returned faces are not in any particular order, and
+ * multiple faces may have the same name or characteristics.
+ *
+ * `PangoFontFamily` also implemented the [iface@Gio.ListModel] interface
+ * for enumerating faces.
  */
 void
 pango_font_family_list_faces (PangoFontFamily  *family,
@@ -2443,7 +2517,7 @@ pango_font_family_real_get_face (PangoFontFamily *family,
   pango_font_family_list_faces (family, &faces, &n_faces);
 
   face = NULL;
-  if (name == NULL)
+  if (name == NULL && n_faces > 0)
     {
       face = faces[0];
     }
@@ -2609,9 +2683,9 @@ pango_font_face_is_synthesized (PangoFontFace  *face)
  *
  * Gets a name representing the style of this face.
  *
- * The name identifies the face among the different faces
- * in the `PangoFontFamily` for the face. It is suitable
- * for displaying to users.
+ * Note that a font family may contain multiple faces
+ * with the same name (e.g. a variable and a non-variable
+ * face for the same style).
  *
  * Return value: the face name for the face. This string is
  *   owned by the face object and must not be modified or freed.
@@ -2687,7 +2761,7 @@ pango_font_face_get_family (PangoFontFace *face)
  *
  * Returns whether the font provides a glyph for this character.
  *
- * Returns %TRUE if @font can render @wc
+ * Returns: `TRUE` if @font can render @wc
  *
  * Since: 1.44
  */
